# perturbopy
Suite of Python scripts for Perturbo testing and postprocessing 

Documentation website: https://perturbopy.readthedocs.io

The conftest.py is the 'entry' script for the perturbo.x tests.
